@@ -387,6 +387,7 @@ class Cursor(object):
     _prep = None
     _rs = None
     _description = None
+    warnings = None
 
     def __init__(self, connection, converters):
         self._connection = connection
@@ -450,6 +451,11 @@ class Cursor(object):
         m_stmt = self._connection.jconn.createStatement()
         try:
             is_rs = m_stmt.execute(operation)
+            m_SQLWarnings = m_stmt.getWarnings()
+            if m_SQLWarnings is not None:
+                self.warnings = m_SQLWarnings.getMessage()
+            else:
+                self.warnings = None
         except:
             _handle_sql_exception_jpype()
         self._rs = m_stmt.getResultSet()
@@ -475,6 +481,11 @@ class Cursor(object):
         is_rs = False
         try:
             is_rs = self._prep.execute()
+            m_SQLWarnings = self._prep.getWarnings()
+            if m_SQLWarnings is not None:
+                self.warnings = m_SQLWarnings.getMessage()
+            else:
+                self.warnings = None
         except:
             _handle_sql_exception_jpype()
         # 忽略对execute的返回判断，总是恒定的去调用getResultSet
@@ -487,7 +498,6 @@ class Cursor(object):
             self.rowcount = -1
         else:
             self.rowcount = self._prep.getUpdateCount()
-        # self._prep.getWarnings() ???
 
     def executemany(self, operation, seq_of_parameters):
         self._close_last()
@@ -727,6 +737,8 @@ def _java_to_py_timestampwithtimezone(conn, rs, col):
     elif m_TypeName in ('oracle.sql.TIMESTAMPTZ', 'oracle.sql.TIMESTAMPLTZ'):
         return java_val.offsetDateTimeValue(conn).format(
             jpype.java.time.format.DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss.SSSSSS Z"))
+    elif m_TypeName in ('org.h2.api.TimestampWithTimeZone'):
+        return java_val.toString()
     else:
         raise SQLCliJDBCException(
             "SQLCLI-00000: Unknown java class type [" + m_TypeName +
@@ -743,7 +755,6 @@ def _java_to_py_clob(conn, rs, col):
         m_TrimLength = int(_sqloptions.get("LOB_LENGTH"))
         if m_TrimLength > m_Length:
             m_TrimLength = m_Length
-        print("Length =" + str(m_TrimLength))
         m_ColumnValue = java_val.getSubString(1, int(m_TrimLength))
         if m_Length > int(m_TrimLength):
             m_ColumnValue = m_ColumnValue + "..."
