@@ -13,8 +13,8 @@ from .sqlparse import SQLFormatWithPrefix
 from .commandanalyze import execute
 from .commandanalyze import CommandNotFound
 from .sqlcliexception import SQLCliException
-from SQLCliODBC import SQLCliODBCException
 from .sqlclijdbcapi import SQLCliJDBCException
+from SQLCliODBC import SQLCliODBCException
 
 
 class SQLExecute(object):
@@ -39,7 +39,7 @@ class SQLExecute(object):
         self.SQLScenario = ''
 
         # Transaction信息
-        self.SQLTransaction = ''
+        self.SQLTransactionName = ""
 
         # 当前SQL游标
         self.cur = None
@@ -160,7 +160,6 @@ class SQLExecute(object):
 
             sql = m_raw_sql                                          # 当前要被执行的SQL，这个SQL可能被随后的注释或者替换规则改写
             m_CommentSQL = ret_SQLSplitResultsWithComments[m_nPos]   # 记录带有注释信息的SQL
-            m_FormattedSQL = None                                    # 已经被格式化了的SQL语句
             m_RewrotedSQL = []                                       # SQL可能会被多次改写
 
             # 分析SQLHint信息
@@ -277,7 +276,6 @@ class SQLExecute(object):
                             "type": "error",
                             "message": "Not connected. "
                         }
-                        return
 
                 # 执行正常的SQL语句
                 if self.cur is not None:
@@ -297,7 +295,8 @@ class SQLExecute(object):
                         rowcount = 0
                         m_SQL_Status = 0
                         while True:
-                            (title, result, headers, columntypes, status, m_FetchStatus, m_FetchedRows) = \
+                            (title, result, headers, columntypes, status,
+                             m_FetchStatus, m_FetchedRows, m_SQLWarnings) = \
                                 self.get_result(self.cur, rowcount)
                             rowcount = m_FetchedRows
                             if "SQLCLI_DEBUG" in os.environ:
@@ -306,11 +305,6 @@ class SQLExecute(object):
                                         for m_CellPos in range(0, len(result[m_RowPos])):
                                             print("Cell[" + str(m_RowPos) + ":" +
                                                   str(m_CellPos) + "]=[" + str(result[m_RowPos][m_CellPos]) + "]")
-                            self.LastJsonSQLResult = {"desc": headers,
-                                                      "rows": rowcount,
-                                                      "elapsed": time.time() - start,
-                                                      "result": result,
-                                                      "status": 0}
 
                             # 如果Hints中有order字样，对结果进行排序后再输出
                             if "Order" in m_SQLHint.keys() and result is not None:
@@ -319,6 +313,14 @@ class SQLExecute(object):
                                         if str(result[j]) > str(result[j + 1]):
                                             result[j], result[j + 1] = result[j + 1], result[j]
 
+                            # 保存之前的运行结果
+                            self.LastJsonSQLResult = {"desc": headers,
+                                                      "rows": rowcount,
+                                                      "elapsed": time.time() - start,
+                                                      "result": result,
+                                                      "status": 0,
+                                                      "warnings": m_SQLWarnings}
+                            
                             # 如果Hint中存在LogFilter，则结果集中过滤指定的输出信息
                             if "LogFilter" in m_SQLHint.keys() and result is not None:
                                 for m_SQLFilter in m_SQLHint["LogFilter"]:
@@ -350,6 +352,7 @@ class SQLExecute(object):
                                                                  re.IGNORECASE)
                                             if m_NewOutput != m_Output:
                                                 result[i] = tuple(m_NewOutput.split('|||'))
+                                                m_Output = m_NewOutput
                                         else:
                                             if "SQLCLI_DEBUG" in os.environ:
                                                 print("LogMask Hint Error: " + m_SQLHint["LogMask"])
@@ -379,10 +382,9 @@ class SQLExecute(object):
                                 self.SQLOptions.set("SILENT", "ON")
                                 self.SQLOptions.set("TIMING", "OFF")
                                 self.SQLOptions.set("TIME", "OFF")
-                                m_LoopFinished = False
                                 for m_nLoopPos in range(0, m_LoopTimes):
                                     # 检查Until条件，如果达到Until条件，退出
-                                    m_AssertSuccessful =False
+                                    m_AssertSuccessful = False
                                     for m_Result in \
                                             self.run("__internal__ test assert " + m_LoopUntil):
                                         if m_Result["type"] == "result":
@@ -522,6 +524,7 @@ class SQLExecute(object):
                     if "SQLCLI_DEBUG" in os.environ:
                         print('traceback.print_exc():\n%s' % traceback.print_exc())
                         print('traceback.format_exc():\n%s' % traceback.format_exc())
+                        print("traceback.pid():" + str(os.getpid()))
                     self.LastJsonSQLResult = None
                     yield {"type": "error", "message": m_SQL_ErrorMessage}
 
@@ -541,11 +544,21 @@ class SQLExecute(object):
                     "ErrorMessage": m_SQL_ErrorMessage,
                     "thread_name": self.WorkerName,
                     "Scenario": self.SQLScenario,
-                    "Transaction": self.SQLTransaction
+                    "Transaction": self.SQLTransactionName
                 }
 
     def get_result(self, cursor, rowcount):
-        """Get the current result's data from the cursor."""
+        """
+            返回的内容：
+                title           输出的前提示信息
+                result          结果数据集
+                headers         表头信息
+                columntypes     结果字段类型
+                status          输出的后提示信息
+                FetchStatus     是否输出完成
+                rowcount        共返回记录行数
+                Warning         警告信息
+        """
         title = headers = None
         m_FetchStatus = True
 
@@ -555,7 +568,10 @@ class SQLExecute(object):
         columntypes = []
         if cursor.description is not None:
             headers = [x[0] for x in cursor.description]
-            status = "{0} row{1} selected."
+            if cursor.warnings is not None:
+                status = "{0} row{1} selected with warnings."
+            else:
+                status = "{0} row{1} selected."
             m_arraysize = int(self.SQLOptions.get("ARRAYSIZE"))
             rowset = cursor.fetchmany(m_arraysize)
             for row in rowset:
@@ -565,7 +581,6 @@ class SQLExecute(object):
                     for column in row:
                         if "SQLCLI_DEBUG" in os.environ:
                             print("DEBUG: COLUMN TYPE TYPE: [" + str(type(column)) + "]")
-                        m_ColumnType = ""
                         if type(column) == int:
                             m_ColumnType = "int"
                         elif type(column) == str:
@@ -620,7 +635,10 @@ class SQLExecute(object):
                 # 已经没有什么可以取的了, 游标结束
                 m_FetchStatus = False
         else:
-            status = "{0} row{1} affected"
+            if cursor.warnings is not None:
+                status = "{0} row{1} affected with warnings."
+            else:
+                status = "{0} row{1} affected."
             rowcount = 0 if cursor.rowcount == -1 else cursor.rowcount
             result = None
             m_FetchStatus = False
@@ -633,4 +651,4 @@ class SQLExecute(object):
             status = status.format(rowcount, "" if rowcount == 1 else "s")
         else:
             status = None
-        return title, result, headers, columntypes, status, m_FetchStatus, rowcount
+        return title, result, headers, columntypes, status, m_FetchStatus, rowcount, cursor.warnings
